Documentation
¶
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
This section is empty.
Types ¶
type Connection ¶
Connection is a struct containing information about a CUPS connection
func NewDefaultConnection ¶
func NewDefaultConnection() *Connection
NewDefaultConnection creates a new default CUPS connection
func (*Connection) Refresh ¶
func (c *Connection) Refresh()
Refresh updates the list of destinations and their state
type Dest ¶
Dest is a struct for each printer
func (*Dest) GetOptions ¶
GetOptions returns a map of the dest options
func (*Dest) TestPrintCustom ¶
TestPrintCustom prints a custom CUPS testpage given the file path
Click to show internal directories.
Click to hide internal directories.